Processor.App.Downloader.downloader.DownloaderFull.unwrap
=========================================================

.. currentmodule:: Processor.App.Downloader.downloader

.. automethod:: DownloaderFull.unwrap